
glyphtools
**********

``_``_`Documentation Status`_

Routines for extracting information from fontTools glyphs

* Free software: Apache Software License 2.0

* Documentation: `https://glyphtools.readthedocs.io`_.
